[llvm-commits] CVS: llvm/include/llvm/Analysis/AliasSetTracker.h

Chris Lattner lattner at cs.uiuc.edu
Sun May 23 16:13:57 PDT 2004


Changes in directory llvm/include/llvm/Analysis:

AliasSetTracker.h updated: 1.12 -> 1.13

---
Log message:

Rename a method


---
Diffs of the changes:  (+3 -3)

Index: llvm/include/llvm/Analysis/AliasSetTracker.h
diff -u llvm/include/llvm/Analysis/AliasSetTracker.h:1.12 llvm/include/llvm/Analysis/AliasSetTracker.h:1.13
--- llvm/include/llvm/Analysis/AliasSetTracker.h:1.12	Sun Mar 14 22:08:18 2004
+++ llvm/include/llvm/Analysis/AliasSetTracker.h	Sun May 23 16:10:42 2004
@@ -264,12 +264,12 @@
   void add(BasicBlock &BB);       // Add all instructions in basic block
   void add(const AliasSetTracker &AST); // Add alias relations from another AST
 
   /// remove method - This method is used to remove a pointer value from the
   /// AliasSetTracker entirely.  It should be used when an instruction is
   /// deleted from the program to update the AST.  If you don't use this, you
   /// would have dangling pointers to deleted instructions.
   ///
-  void remove(Value *PtrVal);
+  void deleteValue(Value *PtrVal);
 
   /// getAliasSets - Return the alias sets that are active.
   const ilist<AliasSet> &getAliasSets() const { return AliasSets; }
@@ -264,12 +264,12 @@
   void add(const AliasSetTracker &AST); // Add alias relations from another AST
 
-  /// remove method - This method is used to remove a pointer value from the
-  /// AliasSetTracker entirely.  It should be used when an instruction is
+  /// deleteValue method - This method is used to remove a pointer value from
+  /// the AliasSetTracker entirely.  It should be used when an instruction is
   /// deleted from the program to update the AST.  If you don't use this, you
   /// would have dangling pointers to deleted instructions.





More information about the llvm-commits mailing list